#ifndef BOOST_SIMD_INCLUDE_CONSTANTS_TWOTOM10_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_CONSTANTS_TWOTOM10_HPP_INCLUDED

#include <boost/simd/constant/include/constants/twotom10.hpp>

#endif
